==> hermes-6.0.0.11.tar.gz: hermes-6.0.0.11/app/models/hermes/picture.rb <==
module Hermes
  # Used for enterprise and enterprises sub-entities
  class Picture
    
    include Hermes::Concerns::CommonFieldsConcern
    
    field :thumb240_id, :type => BSON::ObjectId
    field :thumb1000_id, :type => BSON::ObjectId
    field :full_size_id, :type => BSON::ObjectId

    SIZES = %i[thumb240 thumb1000 full_size]

    SIZES.each do |size|
      define_method(:"#{size}_absolute") do 
        get_absolute_asset(size)
      end
      define_method(:"#{size}") do
        get_relative_asset(size)
      end
    end

    #belongs_to :thumb240, class_name: 'Asset'
    #belongs_to :thumb1000, class_name: 'Asset'
    #belongs_to :full_size, class_name: 'Asset'
    belongs_to :housing_offer, class_name: 'Hermes::HousingOffer', index: true
    
    common_indexes *%i[
      thumb240_id
      thumb1000_id
      full_size_id
    ]
    
    after_create :after_create_actions # https://dev.hermes.openstack.local/admin/families/5d3ea80c4ac06e63808d0fc5/mapping
    after_destroy :after_delete_actions
    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id

    def set_blob(blob)
      self.thumb240_id =ImageTools.store_preview(blob, 240, 240)
      self.thumb1000_id =ImageTools.store_preview(blob, 1000)
      self.full_size_id =ImageTools.store_preview(blob, nil)
    end
    
    def after_create_actions
      housing_offer.add_picture(id.to_s)
    end
    
    def after_delete_actions
      housing_offer.remove_picture(id.to_s)
    end

    def get_absolute_asset(key)
      protocol = Rails.env =='development' ? 'http' : 'https'
      "#{protocol}://#{APP_CONFIG["app_host"]}#{get_relative_asset(key)}"
    end 

    def get_relative_asset(key)
      self["#{key}_id"] && Asset.public_relative_url(self["#{key}_id"].to_s)
    end 

  end
end

==> hermes-6.0.1.31.tar.gz: hermes-6.0.1.31/app/models/hermes/picture.rb <==
module Hermes
  # Used for enterprise and enterprises sub-entities
  class Picture
    
    include Hermes::Concerns::CommonFieldsConcern
    
    field :thumb240_id, :type => BSON::ObjectId
    field :thumb1000_id, :type => BSON::ObjectId
    field :full_size_id, :type => BSON::ObjectId

    SIZES = %i[thumb240 thumb1000 full_size]

    SIZES.each do |size|
      define_method(:"#{size}_absolute") do 
        get_absolute_asset(size)
      end
      define_method(:"#{size}") do
        get_relative_asset(size)
      end
    end

    #belongs_to :thumb240, class_name: 'Asset'
    #belongs_to :thumb1000, class_name: 'Asset'
    #belongs_to :full_size, class_name: 'Asset'
    belongs_to :housing_offer, class_name: 'Hermes::HousingOffer', index: true
    
    common_indexes *%i[
      thumb240_id
      thumb1000_id
      full_size_id
    ]
    
    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id

    after_destroy :remove_from_offer

    def set_blob(blob)
      self.thumb240_id =ImageTools.store_preview(blob, 240, 240)
      self.thumb1000_id =ImageTools.store_preview(blob, 1000)
      self.full_size_id =ImageTools.store_preview(blob, nil)
    end

    def get_absolute_asset(key)
      protocol = Rails.env =='development' ? 'http' : 'https'
      "#{protocol}://#{APP_CONFIG["app_host"]}#{get_relative_asset(key)}"
    end 

    def get_relative_asset(key)
      self["#{key}_id"] && Asset.public_relative_url(self["#{key}_id"].to_s)
    end 

    def remove_from_offer
      housing_offer&.update(ordered_picture_ids: housing_offer.ordered_picture_ids - [id, id.to_s])
    end 

  end
end
